#[non_exhaustive]pub enum ZeroImpedanceRule {
Series,
Reactance,
}Expand description
Which branch denominator a matrix builder uses when deciding whether a branch can contribute a finite admittance or susceptance.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Series
Full series impedance, r² + x². Used by Y_bus, LACPF, B’ in BX mode,
and B’’ in XB mode.
Reactance
Reactance only denominator, x. Used by DC incidence, B’ in XB mode,
and B’’ in BX mode after resistance is zeroed.