skipped_zero_impedance

Function skipped_zero_impedance 

pub fn skipped_zero_impedance(
    case: &IndexedNetwork<'_>,
    rule: ZeroImpedanceRule,
) -> ZeroImpedanceSkips
Count in-service branch rows the given builder rule will skip. This is the shared accounting used by matrix metadata and solver property regressions.